@@ -1,5 +1,5 @@
-from pypi_update import pypi_update
-from pypi_upload import pypi_upload
+from pypk.pypi_update import pypi_update
+from pypk.pypi_upload import pypi_upload
 import os
 from clear_console import clearConsole
 
